|support| |doi| |license| |docker_tag| |docker_pulls| |docker_stars| |gitlab_tag|

.. image:: https://gitlab.com/mayan-edms/mayan-edms/raw/master/docs/_static/mayan_logo_bw.png
    :align: center
    :width: 200
    :height: 200

The most advanced, scalable, and mature open source document management system.

.. image:: https://gitlab.com/mayan-edms/mayan-edms/raw/master/docs/_static/overview.gif
    :align: center
    :width: 300

===============
Getting started
===============

It is very easy to get started with Mayan EDMS, just deploy the official
Docker Compose file.

   .. code-block:: console

       curl https://gitlab.com/mayan-edms/mayan-edms/-/raw/master/docker/docker-compose.yml -O
       curl https://gitlab.com/mayan-edms/mayan-edms/-/raw/master/docker/.env -O
       docker compose up --detach


The complete documentation is available at: https://docs.mayan-edms.com/parts/installation.html

=============
Get the books
=============


.. image:: https://m.media-amazon.com/images/I/61PAvrh303L._SL1293_.jpg
    :align: center
    :width: 150
    :target: https://a.co/d/cqda9uu

.. image:: https://m.media-amazon.com/images/I/61g21N5oQCL._SL1491_.jpg
    :align: center
    :width: 150
    :target: https://a.co/d/9RMXyfn

=========
Tutorials
=========

For more in-depth articles, tutorials, and troubleshooting available in the Knowledge Base.

.. image:: https://docs.mayan-edms.com/_static/knowledge-base.jpg
    :align: center
    :width: 300
    :target: https://sellfy.com/p/um2fkx/

Click the image or visit: https://forum.mayan-edms.com/s/prod_Ogq3lYaoROC02Q

===============
Important links
===============

- `Homepage <http://www.mayan-edms.com>`__
- `Documentation <https://docs.mayan-edms.com>`__
- `Forum <https://forum.mayan-edms.com>`__
- `Source code, issues, bugs <https://gitlab.com/mayan-edms/mayan-edms>`__

.. |docker_layers| image:: https://images.microbadger.com/badges/image/mayanedms/mayanedms.svg
   :target: https://microbadger.com/images/mayanedms/mayanedms

.. |docker_pulls| image:: https://img.shields.io/docker/pulls/mayanedms/mayanedms.svg?style=for-the-badge&logo=docker
   :target: https://hub.docker.com/r/mayanedms/mayanedms/

.. |docker_stars| image:: https://img.shields.io/docker/stars/mayanedms/mayanedms.svg?style=for-the-badge&logo=docker
   :target: https://hub.docker.com/r/mayanedms/mayanedms/

.. |docker_tag| image:: https://img.shields.io/docker/v/mayanedms/mayanedms?style=for-the-badge&sort=semver&logo=docker
   :target: https://hub.docker.com/r/mayanedms/mayanedms

.. |gitlab_tag| image:: https://img.shields.io/gitlab/v/tag/mayan-edms%2Fmayan-edms?style=for-the-badge&sort=semver&logo=gitlab&label=GitLab
   :target: https://gitlab.com/mayan-edms/mayan-edms

.. |pypi| image:: https://img.shields.io/pypi/v/mayan-edms.svg
   :target: https://pypi.org/project/mayan-edms/

.. |license| image:: https://img.shields.io/pypi/l/mayan-edms.svg?style=for-the-badge&logo=opensourceinitiative&logoColor=white&color=008800
   :target: https://gitlab.com/mayan-edms/mayan-edms/blob/master/LICENSE

.. |support| image:: https://img.shields.io/badge/Get_support-brightgreen?style=for-the-badge
   :target: https://www.mayan-edms.com/support/

.. |doi| image:: https://img.shields.io/badge/DOI-10.5281%20%2F%20zenodo.16760961-blue.svg?style=for-the-badge&logo=doi
   :target: https://doi.org/10.5281/zenodo.16760961

